@@ -1,4 +1,4 @@
-/* $Header: /p/tcsh/cvsroot/tcsh/sh.lex.c,v 3.86 2010/05/17 19:36:45 christos Exp $ */
+/* $Header: /p/tcsh/cvsroot/tcsh/sh.lex.c,v 3.87 2011/01/24 17:48:15 christos Exp $ */
 /*
  * sh.lex.c: Lexical analysis into tokens
  */
@@ -32,7 +32,7 @@
  */
 #include "sh.h"
 
-RCSID("$tcsh: sh.lex.c,v 3.86 2010/05/17 19:36:45 christos Exp $")
+RCSID("$tcsh: sh.lex.c,v 3.87 2011/01/24 17:48:15 christos Exp $")
 
 #include "ed.h"
 
@@ -465,7 +465,7 @@ getC1(int flag)
 	/* Catch EOF in the middle of a line.  (An EOF at the beginning of
 	 * a line would have been processed by the readc(0) in lex().) */
 	if (c == CHAR_ERR)
-	    stderror(ERR_EOF);
+	    c = '\n';
 
 	if (c == '$' && (flag & DODOL)) {
 	    getdol();
