@@ -1,4 +1,4 @@
-/* $Header: /p/tcsh/cvsroot/tcsh/tc.os.c,v 3.70 2011/01/09 16:25:29 christos Exp $ */
+/* $Header: /p/tcsh/cvsroot/tcsh/tc.os.c,v 3.72 2011/01/25 13:58:19 christos Exp $ */
 /*
  * tc.os.c: OS Dependent builtin functions
  */
@@ -32,7 +32,7 @@
  */
 #include "sh.h"
 
-RCSID("$tcsh: tc.os.c,v 3.70 2011/01/09 16:25:29 christos Exp $")
+RCSID("$tcsh: tc.os.c,v 3.72 2011/01/25 13:58:19 christos Exp $")
 
 #include "tw.h"
 #include "ed.h"
@@ -1606,3 +1606,20 @@ ttyname(int fd)
     return ttyname;
 }
 #endif /* __ANDROID__ */
+
+#if defined(__CYGWIN__) && !defined(NO_CRYPT)
+#undef CHAR		/* Collides with Win32 API */
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#include <sys/cygwin.h>
+char *
+cygwin_xcrypt(struct passwd *pw, const char *password, const char *expected_pwd)
+{
+    static char invalid_password[] = "\377";
+    HANDLE token = cygwin_logon_user(pw, password);
+    if (token == INVALID_HANDLE_VALUE)
+	return invalid_password;
+    CloseHandle(token);
+    return (char *) expected_pwd;
+}
+#endif /* __CYGWIN__ && !NO_CRYPT */
